# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
RWStepRepr module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_rwsteprepr.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _RWStepRepr
else:
    import _RWStepRepr

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _RWStepRepr.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _RWStepRepr.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepRepr.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepRepr.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _RWStepRepr.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _RWStepRepr.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _RWStepRepr.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _RWStepRepr.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _RWStepRepr.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _RWStepRepr.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepRepr.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepRepr.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepRepr.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepRepr.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepRepr.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepRepr.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _RWStepRepr.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _RWStepRepr:
_RWStepRepr.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _RWStepRepr.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepRepr
import OCC.Core.StepBasic

from enum import IntEnum
from OCC.Core.Exception import *



class RWStepRepr_RWAllAroundShapeAspect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWAllAroundShapeAspect_swiginit(self, _RWStepRepr.new_RWStepRepr_RWAllAroundShapeAspect(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads allaroundshapeaspect.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_AllAroundShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWAllAroundShapeAspect_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_AllAroundShapeAspect
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWAllAroundShapeAspect_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes allaroundshapeaspect.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_AllAroundShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWAllAroundShapeAspect_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWAllAroundShapeAspect

# Register RWStepRepr_RWAllAroundShapeAspect in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWAllAroundShapeAspect_swigregister(RWStepRepr_RWAllAroundShapeAspect)

class RWStepRepr_RWApex(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWApex_swiginit(self, _RWStepRepr.new_RWStepRepr_RWApex(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads apex.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_Apex

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWApex_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_Apex
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWApex_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes apex.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_Apex

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWApex_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWApex

# Register RWStepRepr_RWApex in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWApex_swigregister(RWStepRepr_RWApex)

class RWStepRepr_RWAssemblyComponentUsage(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWAssemblyComponentUsage_swiginit(self, _RWStepRepr.new_RWStepRepr_RWAssemblyComponentUsage(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads assemblycomponentusage.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_AssemblyComponentUsage

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWAssemblyComponentUsage_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_AssemblyComponentUsage
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWAssemblyComponentUsage_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes assemblycomponentusage.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_AssemblyComponentUsage

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWAssemblyComponentUsage_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWAssemblyComponentUsage

# Register RWStepRepr_RWAssemblyComponentUsage in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWAssemblyComponentUsage_swigregister(RWStepRepr_RWAssemblyComponentUsage)

class RWStepRepr_RWAssemblyComponentUsageSubstitute(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWAssemblyComponentUsageSubstitute_swiginit(self, _RWStepRepr.new_RWStepRepr_RWAssemblyComponentUsageSubstitute(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_AssemblyComponentUsageSubstitute

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWAssemblyComponentUsageSubstitute_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_AssemblyComponentUsageSubstitute
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWAssemblyComponentUsageSubstitute_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_AssemblyComponentUsageSubstitute

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWAssemblyComponentUsageSubstitute_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWAssemblyComponentUsageSubstitute

# Register RWStepRepr_RWAssemblyComponentUsageSubstitute in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWAssemblyComponentUsageSubstitute_swigregister(RWStepRepr_RWAssemblyComponentUsageSubstitute)

class RWStepRepr_RWBetweenShapeAspect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWBetweenShapeAspect_swiginit(self, _RWStepRepr.new_RWStepRepr_RWBetweenShapeAspect(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads betweenshapeaspect.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_BetweenShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWBetweenShapeAspect_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_BetweenShapeAspect
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWBetweenShapeAspect_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes betweenshapeaspect.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_BetweenShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWBetweenShapeAspect_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWBetweenShapeAspect

# Register RWStepRepr_RWBetweenShapeAspect in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWBetweenShapeAspect_swigregister(RWStepRepr_RWBetweenShapeAspect)

class RWStepRepr_RWCentreOfSymmetry(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWCentreOfSymmetry_swiginit(self, _RWStepRepr.new_RWStepRepr_RWCentreOfSymmetry(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads centreofsymmetry.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_CentreOfSymmetry

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCentreOfSymmetry_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_CentreOfSymmetry
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCentreOfSymmetry_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes centreofsymmetry.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_CentreOfSymmetry

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCentreOfSymmetry_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWCentreOfSymmetry

# Register RWStepRepr_RWCentreOfSymmetry in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWCentreOfSymmetry_swigregister(RWStepRepr_RWCentreOfSymmetry)

class RWStepRepr_RWCharacterizedRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWCharacterizedRepresentation_swiginit(self, _RWStepRepr.new_RWStepRepr_RWCharacterizedRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_CharacterizedRepresentation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCharacterizedRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_CharacterizedRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCharacterizedRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_CharacterizedRepresentation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCharacterizedRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWCharacterizedRepresentation

# Register RWStepRepr_RWCharacterizedRepresentation in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWCharacterizedRepresentation_swigregister(RWStepRepr_RWCharacterizedRepresentation)

class RWStepRepr_RWCompGroupShAspAndCompShAspAndDatumFeatAndShAsp(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWCompGroupShAspAndCompShAspAndDatumFeatAndShAsp_swiginit(self, _RWStepRepr.new_RWStepRepr_RWCompGroupShAspAndCompShAspAndDatumFeatAndShAsp(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompGroupShAspAndCompShAspAndDatumFeatAndShAsp_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompGroupShAspAndCompShAspAndDatumFeatAndShAsp_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompGroupShAspAndCompShAspAndDatumFeatAndShAsp_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWCompGroupShAspAndCompShAspAndDatumFeatAndShAsp

# Register RWStepRepr_RWCompGroupShAspAndCompShAspAndDatumFeatAndShAsp in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWCompGroupShAspAndCompShAspAndDatumFeatAndShAsp_swigregister(RWStepRepr_RWCompGroupShAspAndCompShAspAndDatumFeatAndShAsp)

class RWStepRepr_RWCompShAspAndDatumFeatAndShAsp(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWCompShAspAndDatumFeatAndShAsp_swiginit(self, _RWStepRepr.new_RWStepRepr_RWCompShAspAndDatumFeatAndShAsp(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_CompShAspAndDatumFeatAndShAsp

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompShAspAndDatumFeatAndShAsp_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_CompShAspAndDatumFeatAndShAsp
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompShAspAndDatumFeatAndShAsp_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_CompShAspAndDatumFeatAndShAsp

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompShAspAndDatumFeatAndShAsp_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWCompShAspAndDatumFeatAndShAsp

# Register RWStepRepr_RWCompShAspAndDatumFeatAndShAsp in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWCompShAspAndDatumFeatAndShAsp_swigregister(RWStepRepr_RWCompShAspAndDatumFeatAndShAsp)

class RWStepRepr_RWCompositeGroupShapeAspect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWCompositeGroupShapeAspect_swiginit(self, _RWStepRepr.new_RWStepRepr_RWCompositeGroupShapeAspect(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads compositegroupshapeaspect.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_CompositeGroupShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompositeGroupShapeAspect_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_CompositeGroupShapeAspect
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompositeGroupShapeAspect_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes compositegroupshapeaspect.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_CompositeGroupShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompositeGroupShapeAspect_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWCompositeGroupShapeAspect

# Register RWStepRepr_RWCompositeGroupShapeAspect in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWCompositeGroupShapeAspect_swigregister(RWStepRepr_RWCompositeGroupShapeAspect)

class RWStepRepr_RWCompositeShapeAspect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWCompositeShapeAspect_swiginit(self, _RWStepRepr.new_RWStepRepr_RWCompositeShapeAspect(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads compositeshapeaspect.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_CompositeShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompositeShapeAspect_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_CompositeShapeAspect
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompositeShapeAspect_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes compositeshapeaspect.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_CompositeShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompositeShapeAspect_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWCompositeShapeAspect

# Register RWStepRepr_RWCompositeShapeAspect in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWCompositeShapeAspect_swigregister(RWStepRepr_RWCompositeShapeAspect)

class RWStepRepr_RWCompoundRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWCompoundRepresentationItem_swiginit(self, _RWStepRepr.new_RWStepRepr_RWCompoundRepresentationItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_CompoundRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompoundRepresentationItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_CompoundRepresentationItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompoundRepresentationItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_CompoundRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWCompoundRepresentationItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWCompoundRepresentationItem

# Register RWStepRepr_RWCompoundRepresentationItem in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWCompoundRepresentationItem_swigregister(RWStepRepr_RWCompoundRepresentationItem)

class RWStepRepr_RWConfigurationDesign(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWConfigurationDesign_swiginit(self, _RWStepRepr.new_RWStepRepr_RWConfigurationDesign(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads configurationdesign.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ConfigurationDesign

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConfigurationDesign_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_ConfigurationDesign
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConfigurationDesign_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes configurationdesign.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ConfigurationDesign

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConfigurationDesign_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWConfigurationDesign

# Register RWStepRepr_RWConfigurationDesign in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWConfigurationDesign_swigregister(RWStepRepr_RWConfigurationDesign)

class RWStepRepr_RWConfigurationEffectivity(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWConfigurationEffectivity_swiginit(self, _RWStepRepr.new_RWStepRepr_RWConfigurationEffectivity(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads configurationeffectivity.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ConfigurationEffectivity

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConfigurationEffectivity_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_ConfigurationEffectivity
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConfigurationEffectivity_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes configurationeffectivity.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ConfigurationEffectivity

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConfigurationEffectivity_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWConfigurationEffectivity

# Register RWStepRepr_RWConfigurationEffectivity in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWConfigurationEffectivity_swigregister(RWStepRepr_RWConfigurationEffectivity)

class RWStepRepr_RWConfigurationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWConfigurationItem_swiginit(self, _RWStepRepr.new_RWStepRepr_RWConfigurationItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads configurationitem.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ConfigurationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConfigurationItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_ConfigurationItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConfigurationItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes configurationitem.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ConfigurationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConfigurationItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWConfigurationItem

# Register RWStepRepr_RWConfigurationItem in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWConfigurationItem_swigregister(RWStepRepr_RWConfigurationItem)

class RWStepRepr_RWConstructiveGeometryRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWConstructiveGeometryRepresentation_swiginit(self, _RWStepRepr.new_RWStepRepr_RWConstructiveGeometryRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ConstructiveGeometryRepresentation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConstructiveGeometryRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_ConstructiveGeometryRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConstructiveGeometryRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ConstructiveGeometryRepresentation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConstructiveGeometryRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWConstructiveGeometryRepresentation

# Register RWStepRepr_RWConstructiveGeometryRepresentation in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWConstructiveGeometryRepresentation_swigregister(RWStepRepr_RWConstructiveGeometryRepresentation)

class RWStepRepr_RWConstructiveGeometryRepresentationRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWConstructiveGeometryRepresentationRelationship_swiginit(self, _RWStepRepr.new_RWStepRepr_RWConstructiveGeometryRepresentationRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ConstructiveGeometryRepresentationRelationship

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConstructiveGeometryRepresentationRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_ConstructiveGeometryRepresentationRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConstructiveGeometryRepresentationRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ConstructiveGeometryRepresentationRelationship

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWConstructiveGeometryRepresentationRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWConstructiveGeometryRepresentationRelationship

# Register RWStepRepr_RWConstructiveGeometryRepresentationRelationship in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWConstructiveGeometryRepresentationRelationship_swigregister(RWStepRepr_RWConstructiveGeometryRepresentationRelationship)

class RWStepRepr_RWContinuosShapeAspect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWContinuosShapeAspect_swiginit(self, _RWStepRepr.new_RWStepRepr_RWContinuosShapeAspect(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads continuosshapeaspect.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ContinuosShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWContinuosShapeAspect_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_ContinuosShapeAspect
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWContinuosShapeAspect_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes continuosshapeaspect.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ContinuosShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWContinuosShapeAspect_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWContinuosShapeAspect

# Register RWStepRepr_RWContinuosShapeAspect in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWContinuosShapeAspect_swigregister(RWStepRepr_RWContinuosShapeAspect)

class RWStepRepr_RWDataEnvironment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWDataEnvironment_swiginit(self, _RWStepRepr.new_RWStepRepr_RWDataEnvironment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads dataenvironment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_DataEnvironment

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWDataEnvironment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_DataEnvironment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWDataEnvironment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes dataenvironment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_DataEnvironment

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWDataEnvironment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWDataEnvironment

# Register RWStepRepr_RWDataEnvironment in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWDataEnvironment_swigregister(RWStepRepr_RWDataEnvironment)

class RWStepRepr_RWDefinitionalRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWDefinitionalRepresentation_swiginit(self, _RWStepRepr.new_RWStepRepr_RWDefinitionalRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_DefinitionalRepresentation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWDefinitionalRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_DefinitionalRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWDefinitionalRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_DefinitionalRepresentation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWDefinitionalRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWDefinitionalRepresentation

# Register RWStepRepr_RWDefinitionalRepresentation in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWDefinitionalRepresentation_swigregister(RWStepRepr_RWDefinitionalRepresentation)

class RWStepRepr_RWDerivedShapeAspect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWDerivedShapeAspect_swiginit(self, _RWStepRepr.new_RWStepRepr_RWDerivedShapeAspect(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads derivedshapeaspect.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_DerivedShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWDerivedShapeAspect_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_DerivedShapeAspect
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWDerivedShapeAspect_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes derivedshapeaspect.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_DerivedShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWDerivedShapeAspect_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWDerivedShapeAspect

# Register RWStepRepr_RWDerivedShapeAspect in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWDerivedShapeAspect_swigregister(RWStepRepr_RWDerivedShapeAspect)

class RWStepRepr_RWDescriptiveRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWDescriptiveRepresentationItem_swiginit(self, _RWStepRepr.new_RWStepRepr_RWDescriptiveRepresentationItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_DescriptiveRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWDescriptiveRepresentationItem_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_DescriptiveRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWDescriptiveRepresentationItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWDescriptiveRepresentationItem

# Register RWStepRepr_RWDescriptiveRepresentationItem in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWDescriptiveRepresentationItem_swigregister(RWStepRepr_RWDescriptiveRepresentationItem)

class RWStepRepr_RWExtension(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWExtension_swiginit(self, _RWStepRepr.new_RWStepRepr_RWExtension(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads extension.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_Extension

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWExtension_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_Extension
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWExtension_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes extension.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_Extension

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWExtension_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWExtension

# Register RWStepRepr_RWExtension in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWExtension_swigregister(RWStepRepr_RWExtension)

class RWStepRepr_RWFeatureForDatumTargetRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWFeatureForDatumTargetRelationship_swiginit(self, _RWStepRepr.new_RWStepRepr_RWFeatureForDatumTargetRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads shapeaspectrelationship.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_FeatureForDatumTargetRelationship

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWFeatureForDatumTargetRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_FeatureForDatumTargetRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWFeatureForDatumTargetRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes shapeaspectrelationship.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_FeatureForDatumTargetRelationship

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWFeatureForDatumTargetRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWFeatureForDatumTargetRelationship

# Register RWStepRepr_RWFeatureForDatumTargetRelationship in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWFeatureForDatumTargetRelationship_swigregister(RWStepRepr_RWFeatureForDatumTargetRelationship)

class RWStepRepr_RWFunctionallyDefinedTransformation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWFunctionallyDefinedTransformation_swiginit(self, _RWStepRepr.new_RWStepRepr_RWFunctionallyDefinedTransformation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_FunctionallyDefinedTransformation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWFunctionallyDefinedTransformation_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_FunctionallyDefinedTransformation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWFunctionallyDefinedTransformation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWFunctionallyDefinedTransformation

# Register RWStepRepr_RWFunctionallyDefinedTransformation in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWFunctionallyDefinedTransformation_swigregister(RWStepRepr_RWFunctionallyDefinedTransformation)

class RWStepRepr_RWGeometricAlignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWGeometricAlignment_swiginit(self, _RWStepRepr.new_RWStepRepr_RWGeometricAlignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads geometricalignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_GeometricAlignment

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWGeometricAlignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_GeometricAlignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWGeometricAlignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes geometricalignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_GeometricAlignment

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWGeometricAlignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWGeometricAlignment

# Register RWStepRepr_RWGeometricAlignment in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWGeometricAlignment_swigregister(RWStepRepr_RWGeometricAlignment)

class RWStepRepr_RWGlobalUncertaintyAssignedContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWGlobalUncertaintyAssignedContext_swiginit(self, _RWStepRepr.new_RWStepRepr_RWGlobalUncertaintyAssignedContext(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_GlobalUncertaintyAssignedContext

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWGlobalUncertaintyAssignedContext_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_GlobalUncertaintyAssignedContext
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWGlobalUncertaintyAssignedContext_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_GlobalUncertaintyAssignedContext

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWGlobalUncertaintyAssignedContext_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWGlobalUncertaintyAssignedContext

# Register RWStepRepr_RWGlobalUncertaintyAssignedContext in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWGlobalUncertaintyAssignedContext_swigregister(RWStepRepr_RWGlobalUncertaintyAssignedContext)

class RWStepRepr_RWGlobalUnitAssignedContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWGlobalUnitAssignedContext_swiginit(self, _RWStepRepr.new_RWStepRepr_RWGlobalUnitAssignedContext(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_GlobalUnitAssignedContext

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWGlobalUnitAssignedContext_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_GlobalUnitAssignedContext
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWGlobalUnitAssignedContext_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_GlobalUnitAssignedContext

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWGlobalUnitAssignedContext_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWGlobalUnitAssignedContext

# Register RWStepRepr_RWGlobalUnitAssignedContext in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWGlobalUnitAssignedContext_swigregister(RWStepRepr_RWGlobalUnitAssignedContext)

class RWStepRepr_RWIntegerRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWIntegerRepresentationItem_swiginit(self, _RWStepRepr.new_RWStepRepr_RWIntegerRepresentationItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_IntegerRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWIntegerRepresentationItem_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_IntegerRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWIntegerRepresentationItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWIntegerRepresentationItem

# Register RWStepRepr_RWIntegerRepresentationItem in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWIntegerRepresentationItem_swigregister(RWStepRepr_RWIntegerRepresentationItem)

class RWStepRepr_RWItemDefinedTransformation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWItemDefinedTransformation_swiginit(self, _RWStepRepr.new_RWStepRepr_RWItemDefinedTransformation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ItemDefinedTransformation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWItemDefinedTransformation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_ItemDefinedTransformation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWItemDefinedTransformation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ItemDefinedTransformation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWItemDefinedTransformation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWItemDefinedTransformation

# Register RWStepRepr_RWItemDefinedTransformation in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWItemDefinedTransformation_swigregister(RWStepRepr_RWItemDefinedTransformation)

class RWStepRepr_RWMakeFromUsageOption(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWMakeFromUsageOption_swiginit(self, _RWStepRepr.new_RWStepRepr_RWMakeFromUsageOption(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads makefromusageoption.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_MakeFromUsageOption

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMakeFromUsageOption_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_MakeFromUsageOption
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMakeFromUsageOption_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes makefromusageoption.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_MakeFromUsageOption

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMakeFromUsageOption_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWMakeFromUsageOption

# Register RWStepRepr_RWMakeFromUsageOption in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWMakeFromUsageOption_swigregister(RWStepRepr_RWMakeFromUsageOption)

class RWStepRepr_RWMappedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWMappedItem_swiginit(self, _RWStepRepr.new_RWStepRepr_RWMappedItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_MappedItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMappedItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_MappedItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMappedItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_MappedItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMappedItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWMappedItem

# Register RWStepRepr_RWMappedItem in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWMappedItem_swigregister(RWStepRepr_RWMappedItem)

class RWStepRepr_RWMaterialDesignation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWMaterialDesignation_swiginit(self, _RWStepRepr.new_RWStepRepr_RWMaterialDesignation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_MaterialDesignation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMaterialDesignation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_MaterialDesignation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMaterialDesignation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_MaterialDesignation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMaterialDesignation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWMaterialDesignation

# Register RWStepRepr_RWMaterialDesignation in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWMaterialDesignation_swigregister(RWStepRepr_RWMaterialDesignation)

class RWStepRepr_RWMaterialProperty(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWMaterialProperty_swiginit(self, _RWStepRepr.new_RWStepRepr_RWMaterialProperty(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads materialproperty.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_MaterialProperty

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMaterialProperty_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_MaterialProperty
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMaterialProperty_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes materialproperty.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_MaterialProperty

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMaterialProperty_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWMaterialProperty

# Register RWStepRepr_RWMaterialProperty in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWMaterialProperty_swigregister(RWStepRepr_RWMaterialProperty)

class RWStepRepr_RWMaterialPropertyRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWMaterialPropertyRepresentation_swiginit(self, _RWStepRepr.new_RWStepRepr_RWMaterialPropertyRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads materialpropertyrepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_MaterialPropertyRepresentation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMaterialPropertyRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_MaterialPropertyRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMaterialPropertyRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes materialpropertyrepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_MaterialPropertyRepresentation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMaterialPropertyRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWMaterialPropertyRepresentation

# Register RWStepRepr_RWMaterialPropertyRepresentation in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWMaterialPropertyRepresentation_swigregister(RWStepRepr_RWMaterialPropertyRepresentation)

class RWStepRepr_RWMeasureRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWMeasureRepresentationItem_swiginit(self, _RWStepRepr.new_RWStepRepr_RWMeasureRepresentationItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_MeasureRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMeasureRepresentationItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_MeasureRepresentationItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMeasureRepresentationItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_MeasureRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWMeasureRepresentationItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWMeasureRepresentationItem

# Register RWStepRepr_RWMeasureRepresentationItem in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWMeasureRepresentationItem_swigregister(RWStepRepr_RWMeasureRepresentationItem)

class RWStepRepr_RWParallelOffset(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWParallelOffset_swiginit(self, _RWStepRepr.new_RWStepRepr_RWParallelOffset(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads paralleloffset.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ParallelOffset

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWParallelOffset_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_ParallelOffset
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWParallelOffset_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes paralleloffset.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ParallelOffset

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWParallelOffset_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWParallelOffset

# Register RWStepRepr_RWParallelOffset in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWParallelOffset_swigregister(RWStepRepr_RWParallelOffset)

class RWStepRepr_RWParametricRepresentationContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWParametricRepresentationContext_swiginit(self, _RWStepRepr.new_RWStepRepr_RWParametricRepresentationContext(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ParametricRepresentationContext

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWParametricRepresentationContext_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ParametricRepresentationContext

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWParametricRepresentationContext_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWParametricRepresentationContext

# Register RWStepRepr_RWParametricRepresentationContext in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWParametricRepresentationContext_swigregister(RWStepRepr_RWParametricRepresentationContext)

class RWStepRepr_RWPerpendicularTo(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWPerpendicularTo_swiginit(self, _RWStepRepr.new_RWStepRepr_RWPerpendicularTo(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads perpendicularto.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_PerpendicularTo

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWPerpendicularTo_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_PerpendicularTo
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWPerpendicularTo_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes perpendicularto.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_PerpendicularTo

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWPerpendicularTo_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWPerpendicularTo

# Register RWStepRepr_RWPerpendicularTo in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWPerpendicularTo_swigregister(RWStepRepr_RWPerpendicularTo)

class RWStepRepr_RWProductConcept(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWProductConcept_swiginit(self, _RWStepRepr.new_RWStepRepr_RWProductConcept(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads productconcept.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ProductConcept

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWProductConcept_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_ProductConcept
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWProductConcept_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes productconcept.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ProductConcept

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWProductConcept_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWProductConcept

# Register RWStepRepr_RWProductConcept in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWProductConcept_swigregister(RWStepRepr_RWProductConcept)

class RWStepRepr_RWProductDefinitionShape(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWProductDefinitionShape_swiginit(self, _RWStepRepr.new_RWStepRepr_RWProductDefinitionShape(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads productdefinitionshape.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ProductDefinitionShape

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWProductDefinitionShape_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_ProductDefinitionShape
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWProductDefinitionShape_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes productdefinitionshape.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ProductDefinitionShape

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWProductDefinitionShape_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWProductDefinitionShape

# Register RWStepRepr_RWProductDefinitionShape in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWProductDefinitionShape_swigregister(RWStepRepr_RWProductDefinitionShape)

class RWStepRepr_RWPropertyDefinition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWPropertyDefinition_swiginit(self, _RWStepRepr.new_RWStepRepr_RWPropertyDefinition(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads propertydefinition.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_PropertyDefinition

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWPropertyDefinition_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_PropertyDefinition
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWPropertyDefinition_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes propertydefinition.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_PropertyDefinition

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWPropertyDefinition_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWPropertyDefinition

# Register RWStepRepr_RWPropertyDefinition in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWPropertyDefinition_swigregister(RWStepRepr_RWPropertyDefinition)

class RWStepRepr_RWPropertyDefinitionRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWPropertyDefinitionRelationship_swiginit(self, _RWStepRepr.new_RWStepRepr_RWPropertyDefinitionRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads propertydefinitionrelationship.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_PropertyDefinitionRelationship

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWPropertyDefinitionRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_PropertyDefinitionRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWPropertyDefinitionRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes propertydefinitionrelationship.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_PropertyDefinitionRelationship

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWPropertyDefinitionRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWPropertyDefinitionRelationship

# Register RWStepRepr_RWPropertyDefinitionRelationship in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWPropertyDefinitionRelationship_swigregister(RWStepRepr_RWPropertyDefinitionRelationship)

class RWStepRepr_RWPropertyDefinitionRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWPropertyDefinitionRepresentation_swiginit(self, _RWStepRepr.new_RWStepRepr_RWPropertyDefinitionRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads propertydefinitionrepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_PropertyDefinitionRepresentation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWPropertyDefinitionRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_PropertyDefinitionRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWPropertyDefinitionRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes propertydefinitionrepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_PropertyDefinitionRepresentation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWPropertyDefinitionRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWPropertyDefinitionRepresentation

# Register RWStepRepr_RWPropertyDefinitionRepresentation in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWPropertyDefinitionRepresentation_swigregister(RWStepRepr_RWPropertyDefinitionRepresentation)

class RWStepRepr_RWQuantifiedAssemblyComponentUsage(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWQuantifiedAssemblyComponentUsage_swiginit(self, _RWStepRepr.new_RWStepRepr_RWQuantifiedAssemblyComponentUsage(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads quantifiedassemblycomponentusage.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_QuantifiedAssemblyComponentUsage

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWQuantifiedAssemblyComponentUsage_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_QuantifiedAssemblyComponentUsage
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWQuantifiedAssemblyComponentUsage_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes quantifiedassemblycomponentusage.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_QuantifiedAssemblyComponentUsage

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWQuantifiedAssemblyComponentUsage_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWQuantifiedAssemblyComponentUsage

# Register RWStepRepr_RWQuantifiedAssemblyComponentUsage in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWQuantifiedAssemblyComponentUsage_swigregister(RWStepRepr_RWQuantifiedAssemblyComponentUsage)

class RWStepRepr_RWReprItemAndLengthMeasureWithUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWReprItemAndLengthMeasureWithUnit_swiginit(self, _RWStepRepr.new_RWStepRepr_RWReprItemAndLengthMeasureWithUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ReprItemAndLengthMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWReprItemAndLengthMeasureWithUnit_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ReprItemAndLengthMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWReprItemAndLengthMeasureWithUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWReprItemAndLengthMeasureWithUnit

# Register RWStepRepr_RWReprItemAndLengthMeasureWithUnit in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWReprItemAndLengthMeasureWithUnit_swigregister(RWStepRepr_RWReprItemAndLengthMeasureWithUnit)

class RWStepRepr_RWReprItemAndLengthMeasureWithUnitAndQRI(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWReprItemAndLengthMeasureWithUnitAndQRI_swiginit(self, _RWStepRepr.new_RWStepRepr_RWReprItemAndLengthMeasureWithUnitAndQRI(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWReprItemAndLengthMeasureWithUnitAndQRI_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWReprItemAndLengthMeasureWithUnitAndQRI_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWReprItemAndLengthMeasureWithUnitAndQRI

# Register RWStepRepr_RWReprItemAndLengthMeasureWithUnitAndQRI in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWReprItemAndLengthMeasureWithUnitAndQRI_swigregister(RWStepRepr_RWReprItemAndLengthMeasureWithUnitAndQRI)

class RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnit_swiginit(self, _RWStepRepr.new_RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ReprItemAndPlaneAngleMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnit_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ReprItemAndPlaneAngleMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnit

# Register RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnit in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnit_swigregister(RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnit)

class RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnitAndQRI(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnitAndQRI_swiginit(self, _RWStepRepr.new_RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnitAndQRI(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnitAndQRI_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnitAndQRI_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnitAndQRI

# Register RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnitAndQRI in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnitAndQRI_swigregister(RWStepRepr_RWReprItemAndPlaneAngleMeasureWithUnitAndQRI)

class RWStepRepr_RWRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWRepresentation_swiginit(self, _RWStepRepr.new_RWStepRepr_RWRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_Representation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_Representation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_Representation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWRepresentation

# Register RWStepRepr_RWRepresentation in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWRepresentation_swigregister(RWStepRepr_RWRepresentation)

class RWStepRepr_RWRepresentationContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWRepresentationContext_swiginit(self, _RWStepRepr.new_RWStepRepr_RWRepresentationContext(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_RepresentationContext

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentationContext_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_RepresentationContext

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentationContext_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWRepresentationContext

# Register RWStepRepr_RWRepresentationContext in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWRepresentationContext_swigregister(RWStepRepr_RWRepresentationContext)

class RWStepRepr_RWRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWRepresentationItem_swiginit(self, _RWStepRepr.new_RWStepRepr_RWRepresentationItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_RepresentationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentationItem_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_RepresentationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentationItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWRepresentationItem

# Register RWStepRepr_RWRepresentationItem in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWRepresentationItem_swigregister(RWStepRepr_RWRepresentationItem)

class RWStepRepr_RWRepresentationMap(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWRepresentationMap_swiginit(self, _RWStepRepr.new_RWStepRepr_RWRepresentationMap(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_RepresentationMap

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentationMap_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_RepresentationMap
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentationMap_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_RepresentationMap

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentationMap_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWRepresentationMap

# Register RWStepRepr_RWRepresentationMap in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWRepresentationMap_swigregister(RWStepRepr_RWRepresentationMap)

class RWStepRepr_RWRepresentationRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWRepresentationRelationship_swiginit(self, _RWStepRepr.new_RWStepRepr_RWRepresentationRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_RepresentationRelationship

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentationRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_RepresentationRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentationRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_RepresentationRelationship

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentationRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWRepresentationRelationship

# Register RWStepRepr_RWRepresentationRelationship in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWRepresentationRelationship_swigregister(RWStepRepr_RWRepresentationRelationship)

class RWStepRepr_RWRepresentationRelationshipWithTransformation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWRepresentationRelationshipWithTransformation_swiginit(self, _RWStepRepr.new_RWStepRepr_RWRepresentationRelationshipWithTransformation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_RepresentationRelationshipWithTransformation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentationRelationshipWithTransformation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_RepresentationRelationshipWithTransformation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentationRelationshipWithTransformation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_RepresentationRelationshipWithTransformation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWRepresentationRelationshipWithTransformation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWRepresentationRelationshipWithTransformation

# Register RWStepRepr_RWRepresentationRelationshipWithTransformation in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWRepresentationRelationshipWithTransformation_swigregister(RWStepRepr_RWRepresentationRelationshipWithTransformation)

class RWStepRepr_RWShapeAspect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWShapeAspect_swiginit(self, _RWStepRepr.new_RWStepRepr_RWShapeAspect(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeAspect_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_ShapeAspect
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeAspect_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ShapeAspect

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeAspect_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWShapeAspect

# Register RWStepRepr_RWShapeAspect in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWShapeAspect_swigregister(RWStepRepr_RWShapeAspect)

class RWStepRepr_RWShapeAspectDerivingRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWShapeAspectDerivingRelationship_swiginit(self, _RWStepRepr.new_RWStepRepr_RWShapeAspectDerivingRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads shapeaspectderivingrelationship.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ShapeAspectDerivingRelationship

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeAspectDerivingRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_ShapeAspectDerivingRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeAspectDerivingRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes shapeaspectderivingrelationship.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ShapeAspectDerivingRelationship

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeAspectDerivingRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWShapeAspectDerivingRelationship

# Register RWStepRepr_RWShapeAspectDerivingRelationship in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWShapeAspectDerivingRelationship_swigregister(RWStepRepr_RWShapeAspectDerivingRelationship)

class RWStepRepr_RWShapeAspectRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWShapeAspectRelationship_swiginit(self, _RWStepRepr.new_RWStepRepr_RWShapeAspectRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads shapeaspectrelationship.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ShapeAspectRelationship

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeAspectRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_ShapeAspectRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeAspectRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes shapeaspectrelationship.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ShapeAspectRelationship

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeAspectRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWShapeAspectRelationship

# Register RWStepRepr_RWShapeAspectRelationship in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWShapeAspectRelationship_swigregister(RWStepRepr_RWShapeAspectRelationship)

class RWStepRepr_RWShapeAspectTransition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWShapeAspectTransition_swiginit(self, _RWStepRepr.new_RWStepRepr_RWShapeAspectTransition(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads shapeaspecttransition.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ShapeAspectTransition

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeAspectTransition_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_ShapeAspectTransition
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeAspectTransition_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes shapeaspecttransition.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ShapeAspectTransition

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeAspectTransition_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWShapeAspectTransition

# Register RWStepRepr_RWShapeAspectTransition in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWShapeAspectTransition_swigregister(RWStepRepr_RWShapeAspectTransition)

class RWStepRepr_RWShapeRepresentationRelationshipWithTransformation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWShapeRepresentationRelationshipWithTransformation_swiginit(self, _RWStepRepr.new_RWStepRepr_RWShapeRepresentationRelationshipWithTransformation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ShapeRepresentationRelationshipWithTransformation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeRepresentationRelationshipWithTransformation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepRepr_ShapeRepresentationRelationshipWithTransformation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeRepresentationRelationshipWithTransformation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ShapeRepresentationRelationshipWithTransformation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWShapeRepresentationRelationshipWithTransformation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWShapeRepresentationRelationshipWithTransformation

# Register RWStepRepr_RWShapeRepresentationRelationshipWithTransformation in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWShapeRepresentationRelationshipWithTransformation_swigregister(RWStepRepr_RWShapeRepresentationRelationshipWithTransformation)

class RWStepRepr_RWSpecifiedHigherUsageOccurrence(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWSpecifiedHigherUsageOccurrence_swiginit(self, _RWStepRepr.new_RWStepRepr_RWSpecifiedHigherUsageOccurrence(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads specifiedhigherusageoccurrence.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_SpecifiedHigherUsageOccurrence

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWSpecifiedHigherUsageOccurrence_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_SpecifiedHigherUsageOccurrence
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWSpecifiedHigherUsageOccurrence_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes specifiedhigherusageoccurrence.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_SpecifiedHigherUsageOccurrence

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWSpecifiedHigherUsageOccurrence_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWSpecifiedHigherUsageOccurrence

# Register RWStepRepr_RWSpecifiedHigherUsageOccurrence in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWSpecifiedHigherUsageOccurrence_swigregister(RWStepRepr_RWSpecifiedHigherUsageOccurrence)

class RWStepRepr_RWStructuralResponseProperty(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWStructuralResponseProperty_swiginit(self, _RWStepRepr.new_RWStepRepr_RWStructuralResponseProperty(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads structuralresponseproperty.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_StructuralResponseProperty

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWStructuralResponseProperty_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_StructuralResponseProperty
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWStructuralResponseProperty_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes structuralresponseproperty.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_StructuralResponseProperty

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWStructuralResponseProperty_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWStructuralResponseProperty

# Register RWStepRepr_RWStructuralResponseProperty in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWStructuralResponseProperty_swigregister(RWStepRepr_RWStructuralResponseProperty)

class RWStepRepr_RWStructuralResponsePropertyDefinitionRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWStructuralResponsePropertyDefinitionRepresentation_swiginit(self, _RWStepRepr.new_RWStepRepr_RWStructuralResponsePropertyDefinitionRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads structuralresponsepropertydefinitionrepresentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_StructuralResponsePropertyDefinitionRepresentation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWStructuralResponsePropertyDefinitionRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_StructuralResponsePropertyDefinitionRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWStructuralResponsePropertyDefinitionRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes structuralresponsepropertydefinitionrepresentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_StructuralResponsePropertyDefinitionRepresentation

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWStructuralResponsePropertyDefinitionRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWStructuralResponsePropertyDefinitionRepresentation

# Register RWStepRepr_RWStructuralResponsePropertyDefinitionRepresentation in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWStructuralResponsePropertyDefinitionRepresentation_swigregister(RWStepRepr_RWStructuralResponsePropertyDefinitionRepresentation)

class RWStepRepr_RWTangent(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWTangent_swiginit(self, _RWStepRepr.new_RWStepRepr_RWTangent(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads tangent.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_Tangent

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWTangent_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepRepr_Tangent
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWTangent_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes tangent.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_Tangent

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWTangent_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWTangent

# Register RWStepRepr_RWTangent in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWTangent_swigregister(RWStepRepr_RWTangent)

class RWStepRepr_RWValueRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepRepr.RWStepRepr_RWValueRepresentationItem_swiginit(self, _RWStepRepr.new_RWStepRepr_RWValueRepresentationItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepRepr_ValueRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWValueRepresentationItem_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepRepr_ValueRepresentationItem

        Returns
        -------
        None

        """
        return _RWStepRepr.RWStepRepr_RWValueRepresentationItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepRepr.delete_RWStepRepr_RWValueRepresentationItem

# Register RWStepRepr_RWValueRepresentationItem in _RWStepRepr:
_RWStepRepr.RWStepRepr_RWValueRepresentationItem_swigregister(RWStepRepr_RWValueRepresentationItem)








##Copyright 2018 Martin Siggel (martin.siggel@dlr.de)
##
##This file is part of pythonOCC.
##
##pythonOCC is free software: you can redistribute it and/or modify
##it under the terms of the GNU Lesser General Public License as published by
##the Free Software Foundation, either version 3 of the License, or
##(at your option) any later version.
##
##pythonOCC is distributed in the hope that it will be useful,
##but WITHOUT ANY WARRANTY; without even the implied warranty of
##MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##GNU Lesser General Public License for more details.
##
##You should have received a copy of the GNU Lesser General Public License
##along with pythonOCC.  If not, see <http://www.gnu.org/licenses/>.

import warnings

def deprecated(message):
    def deprecated_decorator(func):
        def deprecated_func(*args, **kwargs):
            warnings.warn("{} is a deprecated function. {}".format(func.__name__, message),
                          category=DeprecationWarning,
                          stacklevel=2)
            warnings.simplefilter('default', DeprecationWarning)
            return func(*args, **kwargs)
        return deprecated_func
    return deprecated_decorator

class Proxy(object):
    __slots__ = ["_obj", "__weakref__"]
    def __init__(self, obj):
        object.__setattr__(self, "_obj", obj)

    #
    # proxying (special cases)
    #
    def __getattribute__(self, name):
        return getattr(object.__getattribute__(self, "_obj"), name)
    def __delattr__(self, name):
        delattr(object.__getattribute__(self, "_obj"), name)
    def __setattr__(self, name, value):
        setattr(object.__getattribute__(self, "_obj"), name, value)

    def __nonzero__(self):
        return bool(object.__getattribute__(self, "_obj"))
    def __str__(self):
        return str(object.__getattribute__(self, "_obj"))
    def __repr__(self):
        return repr(object.__getattribute__(self, "_obj"))

    #
    # factories
    #
    _special_names = [
        '__abs__', '__add__', '__and__', '__call__', '__cmp__', '__coerce__',
        '__contains__', '__delitem__', '__delslice__', '__div__', '__divmod__',
        '__eq__', '__float__', '__floordiv__', '__ge__', '__getitem__',
        '__getslice__', '__gt__', '__hash__', '__hex__', '__iadd__', '__iand__',
        '__idiv__', '__idivmod__', '__ifloordiv__', '__ilshift__', '__imod__',
        '__imul__', '__int__', '__invert__', '__ior__', '__ipow__', '__irshift__',
        '__isub__', '__iter__', '__itruediv__', '__ixor__', '__le__', '__len__',
        '__long__', '__lshift__', '__lt__', '__mod__', '__mul__', '__ne__',
        '__neg__', '__oct__', '__or__', '__pos__', '__pow__', '__radd__',
        '__rand__', '__rdiv__', '__rdivmod__', '__reduce__', '__reduce_ex__',
        '__repr__', '__reversed__', '__rfloorfiv__', '__rlshift__', '__rmod__',
        '__rmul__', '__ror__', '__rpow__', '__rrshift__', '__rshift__', '__rsub__',
        '__rtruediv__', '__rxor__', '__setitem__', '__setslice__', '__sub__',
        '__truediv__', '__xor__', 'next',
    ]

    @classmethod
    def _create_class_proxy(cls, theclass):
        """creates a proxy for the given class"""

        def make_method(name):
            def method(self, *args, **kw):
                return getattr(object.__getattribute__(self, "_obj"), name)(*args, **kw)
            return method

        namespace = {}
        for name in cls._special_names:
            if hasattr(theclass, name):
                namespace[name] = make_method(name)
        return type("%s(%s)" % (cls.__name__, theclass.__name__), (cls,), namespace)

    def __new__(cls, obj, *args, **kwargs):
        """
        creates an proxy instance referencing `obj`. (obj, *args, **kwargs) are
        passed to this class' __init__, so deriving classes can define an
        __init__ method of their own.
        note: _class_proxy_cache is unique per deriving class (each deriving
        class must hold its own cache)
        """
        try:
            cache = cls.__dict__["_class_proxy_cache"]
        except KeyError:
            cls._class_proxy_cache = cache = {}
        try:
            theclass = cache[obj.__class__]
        except KeyError:
            cache[obj.__class__] = theclass = cls._create_class_proxy(obj.__class__)
        ins = object.__new__(theclass)
        theclass.__init__(ins, obj, *args, **kwargs)
        return ins
